# imports
import os
import json
import csv
import time

# vars
maindir = (os.path.dirname(os.path.realpath(__file__)))


class mainclass():

    # main functions
    def main():
        script = "def main(): \n     print('hello world!') \nmain()"
        f = open("main.py", "a+")
        f.truncate(0)
        f.write(script)
        f.close()
        time.sleep(2)
        exec(open(maindir + '\main.py').read())

    # run function main
    main()



from setuptools import setup, find_packages

VERSION = '0.0.1'
DESCRIPTION = 'A simple auto python setup from command line'
LONG_DESCRIPTION = 'A simple auto python setup from command line, when you run the command it will make a full dirrectory and example code'

setup(
    name="pythonautoloader",
    version=VERSION,
    author="Landen Fisher",
    author_email="landen6002@hotmail.com",
    description=DESCRIPTION,
    long_description=LONG_DESCRIPTION,
    packages=find_packages(),
    install_requires=[],

    keywords=['python', 'first package'],
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Education",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 3",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)
